@@ -16,13 +16,22 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  * $Log: text.h,v $
+ * Revision 1.6  2004/08/22 10:34:24  nigelhorne
+ * Use fileblob
+ *
+ * Revision 1.5  2004/08/21 11:57:57  nigelhorne
+ * Use line.[ch]
+ *
+ * Revision 1.4  2004/07/20 14:35:29  nigelhorne
+ * Some MYDOOM.I were getting through
+ *
  * Revision 1.3  2004/06/22 04:08:02  nigelhorne
  * Optimise empty lines
  *
  */
 
 typedef struct text {
-	char	*t_text;	/* NULL if the line is empty */
+	line_t	*t_line;	/* NULL if the line is empty */
 	struct	text	*t_next;
 } text;
 
@@ -32,5 +41,6 @@ void	textDestroy(text *t_head);
 text	*textClean(text *t_head);
 text	*textCopy(const text *t_head);
 text	*textAdd(text *t_head, const text *t);
-text	*textAddMessage(text *aText, const message *aMessage);
+text	*textAddMessage(text *aText, message *aMessage);
 blob	*textToBlob(const text *t, blob *b);
+fileblob	*textToFileblob(const text *t, fileblob *fb);
